@@ -131,13 +131,14 @@ from .shortnumberinfo import (ShortNumberCost,
                               expected_cost,
                               connects_to_emergency_number,
                               is_emergency_number,
-                              is_carrier_specific)
+                              is_carrier_specific,
+                              is_carrier_specific_for_region)
 from .phonenumbermatcher import PhoneNumberMatch, PhoneNumberMatcher, Leniency
 
 
 # Version number is taken from the upstream libphonenumber version
 # together with an indication of the version of the Python-specific code.
-__version__ = "8.0.0"
+__version__ = "8.1.0"
 
 __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'REGION_CODE_FOR_NON_GEO_ENTITY', 'NumberFormat', 'PhoneNumberDesc', 'PhoneMetadata',
@@ -198,6 +199,7 @@ __all__ = ['PhoneNumber', 'CountryCodeSource', 'FrozenPhoneNumber',
            'connects_to_emergency_number',
            'is_emergency_number',
            'is_carrier_specific',
+           'is_carrier_specific_for_region',
            # end of items from shortnumberinfo.py
            'PhoneNumberMatch', 'PhoneNumberMatcher', 'Leniency',
            ]
